@@ -115,7 +115,7 @@ class Pg:
         columns = ' AND '.join(f'{c} = ${i}' for i, c in enums if i != 1) 
         print('無し' if not columns else f'カラム: {columns}')
 
-        if columns is None:
+        if not columns:
             return await self.pool.execute(f'UPDATE {self.table} SET {one_column}', *opt.values())
 
         await self.pool.execute(f'UPDATE {self.table} SET {one_column} WHERE {columns}', *opt.values())
